@@ -15,21 +15,16 @@ class EmailAuthBackend(object):
         :rtype:
         """
 
-        print "AUTH ", username, " ,", password
         user_model = get_user_model()
     
         try:
             user = user_model.objects.get(email=username)
 
-            print "AUTH FOUND", username
             if user.check_password(password):
-                print "AUTH FOUND PASS GOOD", username
                 return user
         except user_model.DoesNotExist:
-            print "AUTH NOT FOUND", username
             return None
 
-        print "AUTH FOUND PASS NO GOOD", username
     # authenticate()
 
     def get_user(self, user_id):
@@ -42,7 +37,6 @@ class EmailAuthBackend(object):
         """
         user_model = get_user_model()
 
-        print "GET USER", user_id
         try:
             return user_model.objects.get(pk=user_id)
         except user_model.DoesNotExist:
